@@ -4,7 +4,7 @@
 #include <hildon/hildon-program.h>
 #include <gtk/gtk.h>
 
-#define BULLSHIT_BINGO_STORE_FILE "/usr/share/bullshitbingo/dictionary"
+#define BULLSHIT_BINGO_STORE_FILE ".bullshitbingo/dictionary"
 
 void  dict_prepare();
 gint  dict_size();
